OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "สวัสดี %s",
    "Hello %s," : "สวัสดีคุณ %s",
    "Notifications" : "การแจ้งเตือน",
    "Dismiss" : "ยกเลิก",
    "seconds ago" : "วินาที ก่อนหน้านี้",
    "in {path}" : "ใน {เส้นทาง}",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Never" : "ไม่เคย",
    "1 hour" : "1 ชั่วโมง",
    "Your settings have been updated." : "อัปเดตการตั้งค่าของคุณแล้ว"
},
"nplurals=1; plural=0;");
